(function() {
  var Config, FolderConfig, any, defineProperty, getKeys, isArray, isFunction, isObject, isString,
    indexOf = [].indexOf || function(item) { for (var i = 0, l = this.length; i < l; i++) { if (i in this && this[i] === item) return i; } return -1; };

  any = require('promise.any');

  isArray = require('util-ex/lib/is/type/array');

  isString = require('util-ex/lib/is/type/string');

  isObject = require('util-ex/lib/is/type/object');

  isFunction = require('util-ex/lib/is/type/function');

  defineProperty = require('util-ex/lib/defineProperty');

  Config = require('load-config-file');

  getKeys = Object.keys;

  FolderConfig = (function() {
    var fs, path, readFile;

    FolderConfig.prototype.configurators = {};

    FolderConfig.prototype.files = [];

    FolderConfig.prototype.fs = fs = null;

    FolderConfig.prototype.path = path = require('path.js');

    FolderConfig.prototype.readFile = readFile = null;

    function FolderConfig(aPath, aOptions, done) {
      var result;
      if (!(this instanceof FolderConfig)) {
        if (isFunction(aOptions)) {
          done = aOptions;
          aOptions = null;
        }
        if (isFunction(done)) {
          result = FolderConfig.load(aPath, aOptions, done);
        } else {
          result = FolderConfig.loadSync(aPath, aOptions);
        }
        return result;
      }
      this.path = aPath;
      if (isObject(aOptions)) {
        this.options = aOptions;
      }
    }

    FolderConfig.prototype.load = function(aPath, aOptions, done) {
      if (isObject(aPath)) {
        done = aOptions;
        aOptions = aPath;
        aPath = null;
      } else if (isFunction(aPath)) {
        done = aPath;
        aPath = null;
        aOptions = null;
      } else if (isFunction(aOptions)) {
        done = aOptions;
        aOptions = null;
      }
      if (aPath == null) {
        aPath = this.path;
      }
      if (aOptions == null) {
        aOptions = this.options;
      }
      return FolderConfig.load(aPath, aOptions, done);
    };

    FolderConfig.prototype.loadSync = function(aPath, aOptions) {
      if (isObject(aPath)) {
        aOptions = aPath;
        aPath = null;
      }
      if (aPath == null) {
        aPath = this.path;
      }
      if (aOptions == null) {
        aOptions = this.options;
      }
      return FolderConfig.loadSync(aPath, aOptions);
    };

    FolderConfig.addConfig = function(aFile, aConfigFiles) {
      var f, i, len, result;
      if (aConfigFiles == null) {
        aConfigFiles = FolderConfig.prototype.files;
      }
      result = 0;
      if (isString(aFile) && !(indexOf.call(aConfigFiles, aFile) >= 0)) {
        aConfigFiles.push(aFile);
        result++;
      } else if (isArray(aFile)) {
        for (i = 0, len = aFile.length; i < len; i++) {
          f = aFile[i];
          if (indexOf.call(aConfigFiles, aFile) < 0) {
            aConfigFiles.push(f);
            result++;
          }
        }
      }
      return result;
    };

    FolderConfig.load = function(aPath, aOptions, done) {
      var raiseError, vFiles;
      if (aOptions == null) {
        aOptions = {};
      }
      if (aOptions.encoding == null) {
        aOptions.encoding = 'utf8';
      }
      if (!isObject(aOptions.configurators)) {
        defineProperty(aOptions, 'configurators', FolderConfig.prototype.configurators);
      }
      if (isString(aOptions.file)) {
        vFiles = [aOptions.file];
      } else if (isArray(aOptions.file)) {
        vFiles = aOptions.file;
      } else {
        vFiles = FolderConfig.prototype.files;
      }
      raiseError = aOptions.raiseError;
      defineProperty(aOptions, 'raiseError', true);
      return any(vFiles.map(function(name) {
        return Config.load(path.join(aPath, name), aOptions);
      }))["catch"](function(err) {
        if (raiseError) {
          throw err;
        }
      }).asCallback(done);
    };

    FolderConfig.loadSync = function(aPath, aOptions) {
      var i, len, name, result, vFiles;
      if (aOptions == null) {
        aOptions = {};
      }
      if (aOptions.encoding == null) {
        aOptions.encoding = 'utf8';
      }
      if (!isObject(aOptions.configurators)) {
        defineProperty(aOptions, 'configurators', FolderConfig.prototype.configurators);
      }
      if (isString(aOptions.file)) {
        vFiles = [aOptions.file];
      } else if (isArray(aOptions.file)) {
        vFiles = aOptions.file;
      } else {
        vFiles = FolderConfig.prototype.files;
      }
      for (i = 0, len = vFiles.length; i < len; i++) {
        name = vFiles[i];
        result = Config.loadSync(path.join(aPath, name), aOptions);
        if (result) {
          break;
        }
      }
      return result;
    };

    FolderConfig.register = function(aExts, aProcess, aConfigurators) {
      if (aConfigurators == null) {
        aConfigurators = FolderConfig.prototype.configurators;
      }
      return Config.register(aExts, aProcess, aConfigurators);
    };

    FolderConfig.setFileSystem = function(aFileSystem) {
      if (Config.setFileSystem(aFileSystem)) {
        FolderConfig.prototype.fs = fs = aFileSystem;
        if (aFileSystem.path) {
          FolderConfig.prototype.path = path = aFileSystem.path;
        }
        FolderConfig.prototype.readFile = readFile = fs.readFile;
        return true;
      }
    };

    return FolderConfig;

  })();

  FolderConfig.setFileSystem(require('fs'));

  module.exports = FolderConfig;

  module.exports["default"] = FolderConfig;

}).call(this);

//# sourceMappingURL=index.js.map
